[libcamera-devel,1/5] ipa: vimc: Rename ipa_dummy to ipa_vimc

Message ID 20191003152037.74617-2-jacopo@jmondi.org
State Superseded
Headers show
Series
  • test: Add IPA interface test support
Related show

Commit Message

Jacopo Mondi Oct. 3, 2019, 3:20 p.m. UTC
The DummyIPA is actually a test IPA module for the virtual media
controller driver VIMC. Rename it accordingly to its usage.

Signed-off-by: Jacopo Mondi <jacopo@jmondi.org>
---
 src/ipa/{ipa_dummy.cpp => ipa_vimc.cpp} | 10 +++++-----
 src/ipa/meson.build                     | 10 +++++-----
 test/ipa/ipa_test.cpp                   |  2 +-
 3 files changed, 11 insertions(+), 11 deletions(-)
 rename src/ipa/{ipa_dummy.cpp => ipa_vimc.cpp} (71%)

Comments

Laurent Pinchart Oct. 3, 2019, 3:50 p.m. UTC | #1
Hi Jacopo,

Thank you for the patch.

On Thu, Oct 03, 2019 at 05:20:33PM +0200, Jacopo Mondi wrote:
> The DummyIPA is actually a test IPA module for the virtual media
> controller driver VIMC. Rename it accordingly to its usage.
> 
> Signed-off-by: Jacopo Mondi <jacopo@jmondi.org>

Reviewed-by: Laurent Pinchart <laurent.pinchart@ideasonboard.com>

> ---
>  src/ipa/{ipa_dummy.cpp => ipa_vimc.cpp} | 10 +++++-----
>  src/ipa/meson.build                     | 10 +++++-----
>  test/ipa/ipa_test.cpp                   |  2 +-
>  3 files changed, 11 insertions(+), 11 deletions(-)
>  rename src/ipa/{ipa_dummy.cpp => ipa_vimc.cpp} (71%)
> 
> diff --git a/src/ipa/ipa_dummy.cpp b/src/ipa/ipa_vimc.cpp
> similarity index 71%
> rename from src/ipa/ipa_dummy.cpp
> rename to src/ipa/ipa_vimc.cpp
> index 9d0cbdc8b1ad..abc06e7f5fd5 100644
> --- a/src/ipa/ipa_dummy.cpp
> +++ b/src/ipa/ipa_vimc.cpp
> @@ -2,7 +2,7 @@
>  /*
>   * Copyright (C) 2019, Google Inc.
>   *
> - * ipa_dummy.cpp - Dummy Image Processing Algorithm module
> + * ipa_vimc.cpp - Vimc Image Processing Algorithm module
>   */
>  
>  #include <iostream>
> @@ -12,15 +12,15 @@
>  
>  namespace libcamera {
>  
> -class IPADummy : public IPAInterface
> +class IPAVimc : public IPAInterface
>  {
>  public:
>  	int init();
>  };
>  
> -int IPADummy::init()
> +int IPAVimc::init()
>  {
> -	std::cout << "initializing dummy IPA!" << std::endl;
> +	std::cout << "initializing vimc IPA!" << std::endl;
>  	return 0;
>  }
>  
> @@ -39,7 +39,7 @@ const struct IPAModuleInfo ipaModuleInfo = {
>  
>  IPAInterface *ipaCreate()
>  {
> -	return new IPADummy();
> +	return new IPAVimc();
>  }
>  };
>  
> diff --git a/src/ipa/meson.build b/src/ipa/meson.build
> index f09915bc1388..b5bcd7b2c3db 100644
> --- a/src/ipa/meson.build
> +++ b/src/ipa/meson.build
> @@ -1,12 +1,12 @@
> -ipa_dummy_sources = [
> -    ['ipa_dummy',         'LGPL-2.1-or-later'],
> -    ['ipa_dummy_isolate', 'Proprietary'],
> +ipa_vimc_sources = [
> +    ['ipa_vimc',         'LGPL-2.1-or-later'],
> +    ['ipa_vimc_isolate', 'Proprietary'],
>  ]
>  
>  ipa_install_dir = join_paths(get_option('libdir'), 'libcamera')
>  
> -foreach t : ipa_dummy_sources
> -    ipa = shared_module(t[0], 'ipa_dummy.cpp',
> +foreach t : ipa_vimc_sources
> +    ipa = shared_module(t[0], 'ipa_vimc.cpp',
>                          name_prefix : '',
>                          include_directories : libcamera_includes,
>                          install : true,
> diff --git a/test/ipa/ipa_test.cpp b/test/ipa/ipa_test.cpp
> index b9e1bd61c299..8f9b2d8058ec 100644
> --- a/test/ipa/ipa_test.cpp
> +++ b/test/ipa/ipa_test.cpp
> @@ -62,7 +62,7 @@ protected:
>  			"GPL-2.0-or-later",
>  		};
>  
> -		count += runTest("src/ipa/ipa_dummy.so", testInfo);
> +		count += runTest("src/ipa/ipa_vimc.so", testInfo);
>  
>  		if (count < 0)
>  			return TestFail;
Niklas Söderlund Oct. 3, 2019, 8:26 p.m. UTC | #2
Hi Jacopo,

Thanks for your work.

On 2019-10-03 17:20:33 +0200, Jacopo Mondi wrote:
> The DummyIPA is actually a test IPA module for the virtual media
> controller driver VIMC. Rename it accordingly to its usage.
> 
> Signed-off-by: Jacopo Mondi <jacopo@jmondi.org>

Reviewed-by: Niklas Söderlund <niklas.soderlund@ragnatech.se>

> ---
>  src/ipa/{ipa_dummy.cpp => ipa_vimc.cpp} | 10 +++++-----
>  src/ipa/meson.build                     | 10 +++++-----
>  test/ipa/ipa_test.cpp                   |  2 +-
>  3 files changed, 11 insertions(+), 11 deletions(-)
>  rename src/ipa/{ipa_dummy.cpp => ipa_vimc.cpp} (71%)
> 
> diff --git a/src/ipa/ipa_dummy.cpp b/src/ipa/ipa_vimc.cpp
> similarity index 71%
> rename from src/ipa/ipa_dummy.cpp
> rename to src/ipa/ipa_vimc.cpp
> index 9d0cbdc8b1ad..abc06e7f5fd5 100644
> --- a/src/ipa/ipa_dummy.cpp
> +++ b/src/ipa/ipa_vimc.cpp
> @@ -2,7 +2,7 @@
>  /*
>   * Copyright (C) 2019, Google Inc.
>   *
> - * ipa_dummy.cpp - Dummy Image Processing Algorithm module
> + * ipa_vimc.cpp - Vimc Image Processing Algorithm module
>   */
>  
>  #include <iostream>
> @@ -12,15 +12,15 @@
>  
>  namespace libcamera {
>  
> -class IPADummy : public IPAInterface
> +class IPAVimc : public IPAInterface
>  {
>  public:
>  	int init();
>  };
>  
> -int IPADummy::init()
> +int IPAVimc::init()
>  {
> -	std::cout << "initializing dummy IPA!" << std::endl;
> +	std::cout << "initializing vimc IPA!" << std::endl;
>  	return 0;
>  }
>  
> @@ -39,7 +39,7 @@ const struct IPAModuleInfo ipaModuleInfo = {
>  
>  IPAInterface *ipaCreate()
>  {
> -	return new IPADummy();
> +	return new IPAVimc();
>  }
>  };
>  
> diff --git a/src/ipa/meson.build b/src/ipa/meson.build
> index f09915bc1388..b5bcd7b2c3db 100644
> --- a/src/ipa/meson.build
> +++ b/src/ipa/meson.build
> @@ -1,12 +1,12 @@
> -ipa_dummy_sources = [
> -    ['ipa_dummy',         'LGPL-2.1-or-later'],
> -    ['ipa_dummy_isolate', 'Proprietary'],
> +ipa_vimc_sources = [
> +    ['ipa_vimc',         'LGPL-2.1-or-later'],
> +    ['ipa_vimc_isolate', 'Proprietary'],
>  ]
>  
>  ipa_install_dir = join_paths(get_option('libdir'), 'libcamera')
>  
> -foreach t : ipa_dummy_sources
> -    ipa = shared_module(t[0], 'ipa_dummy.cpp',
> +foreach t : ipa_vimc_sources
> +    ipa = shared_module(t[0], 'ipa_vimc.cpp',
>                          name_prefix : '',
>                          include_directories : libcamera_includes,
>                          install : true,
> diff --git a/test/ipa/ipa_test.cpp b/test/ipa/ipa_test.cpp
> index b9e1bd61c299..8f9b2d8058ec 100644
> --- a/test/ipa/ipa_test.cpp
> +++ b/test/ipa/ipa_test.cpp
> @@ -62,7 +62,7 @@ protected:
>  			"GPL-2.0-or-later",
>  		};
>  
> -		count += runTest("src/ipa/ipa_dummy.so", testInfo);
> +		count += runTest("src/ipa/ipa_vimc.so", testInfo);
>  
>  		if (count < 0)
>  			return TestFail;
> -- 
> 2.23.0
> 
> _______________________________________________
> libcamera-devel mailing list
> libcamera-devel@lists.libcamera.org
> https://lists.libcamera.org/listinfo/libcamera-devel

Patch

diff --git a/src/ipa/meson.build b/src/ipa/meson.build
index f09915bc1388..b5bcd7b2c3db 100644
--- a/src/ipa/meson.build
+++ b/src/ipa/meson.build
@@ -1,12 +1,12 @@ 
-ipa_dummy_sources = [
-    ['ipa_dummy',         'LGPL-2.1-or-later'],
-    ['ipa_dummy_isolate', 'Proprietary'],
+ipa_vimc_sources = [
+    ['ipa_vimc',         'LGPL-2.1-or-later'],
+    ['ipa_vimc_isolate', 'Proprietary'],
 ]
 
 ipa_install_dir = join_paths(get_option('libdir'), 'libcamera')
 
-foreach t : ipa_dummy_sources
-    ipa = shared_module(t[0], 'ipa_dummy.cpp',
+foreach t : ipa_vimc_sources
+    ipa = shared_module(t[0], 'ipa_vimc.cpp',
                         name_prefix : '',
                         include_directories : libcamera_includes,
                         install : true,
diff --git a/test/ipa/ipa_test.cpp b/test/ipa/ipa_test.cpp
index b9e1bd61c299..8f9b2d8058ec 100644
--- a/test/ipa/ipa_test.cpp
+++ b/test/ipa/ipa_test.cpp
@@ -62,7 +62,7 @@  protected:
 			"GPL-2.0-or-later",
 		};
 
-		count += runTest("src/ipa/ipa_dummy.so", testInfo);
+		count += runTest("src/ipa/ipa_vimc.so", testInfo);
 
 		if (count < 0)
 			return TestFail;
diff --git a/src/ipa/ipa_dummy.cpp b/src/ipa/ipa_vimc.cpp
similarity index 71%
rename from src/ipa/ipa_dummy.cpp
rename to src/ipa/ipa_vimc.cpp
index 9d0cbdc8b1ad..abc06e7f5fd5 100644
--- a/src/ipa/ipa_dummy.cpp
+++ b/src/ipa/ipa_vimc.cpp
@@ -2,7 +2,7 @@ 
 /*
  * Copyright (C) 2019, Google Inc.
  *
  * ipa_dummy.cpp - Dummy Image Processing Algorithm module
  */
 
 #include <iostream>
@@ -12,15 +12,15 @@ 
 
 namespace libcamera {
 
-class IPADummy : public IPAInterface
+class IPAVimc : public IPAInterface
 {
 public:
 	int init();
 };
 
-int IPADummy::init()
+int IPAVimc::init()
 {
-	std::cout << "initializing dummy IPA!" << std::endl;
+	std::cout << "initializing vimc IPA!" << std::endl;
 	return 0;
 }
 
@@ -39,7 +39,7 @@  const struct IPAModuleInfo ipaModuleInfo = {
 
 IPAInterface *ipaCreate()
 {
-	return new IPADummy();
+	return new IPAVimc();
 }
 };
 
@@ -2,7 +2,7 @@ 
  * Copyright (C) 2019, Google Inc.
  *
- * ipa_dummy.cpp - Dummy Image Processing Algorithm module
+ * ipa_vimc.cpp - Vimc Image Processing Algorithm module
  */
 